Supreme and Appellate Opinions

# New Jersey Courts

## Related Content

- Appellate Division Unpublished Opinions
- Business Related Opinions
- Disciplinary Review Board Decisions
- Opinions Expected for Release
- Trial Court Published Opinions
- Trial Court Unpublished Opinions

## Supreme and Appellate Opinions

Listed on this page are opinions issued by the New Jersey Supreme Court and Appellate Division, Superior Court. These opinions will be made available for 10 business days, after 10 business days you may access the opinions through Rutgers Newark Law School. Opinions are posted in Adobe .pdf. format and require the download of Adobe Reader.

Rutgers Newark Law School hosts a searchable database of New Jersey Supreme Court and Appellate Court reported opinions dating from March 1994 to the present. Also on that web site is a full text archive of the opinions of the Advisory Committee on Professional Ethics, Committee on the Unauthorized Practice of Law, and the Committee on Attorney Advertising.

## Supreme Court Opinions

Date | Appeal # | Title
--- | --- | ---
May, 8, 2013 | A-119-11 | State v. Shaffona Morgan (069967) (Mercer County and Statewide) Argued 3/11/13
Aug. 7, 2013 | A-9-12 | Michael E. Hirsch v. Amper Financial Services, LLC (070751) (Monmouth County and Statewide) Argued 5/13/13
Aug. 6, 2013 | A-117-11 | A-117-11 Norfolk Southern Railway Co. v. Intermodal Properties, LLC (070240) (Statewide) Argued 5/14/13
Aug. 5, 2013 | A-52-11 | Ten Stary Dom Partnership v. T. Brent Mauro (069079) (Ocean County and Statewide) Argued 11/5/12
Aug. 2, 2013 | --- | No Supreme Court opinions reported.
Aug. 1, 2013 | --- | No Supreme Court opinions reported.
July 31, 2013 | --- | No Supreme Court opinions reported.
July 30, 2013 | A-109-11 | State v. Samander S. Dabas (069498) (Middlesex County and Statewide) Argued 3/11/13
July 29, 2013 | A-93-11 | State v. Bruce D. Sterling (068952) (Middlesex County and Statewide) Argued 1/28/13
July 26, 2013 | --- | No Supreme Court opinions reported.

Squibs: 2012-13 |2011-12 |2010-11 |2009-10 |2008-09 | 2007-08 | 2006-07

## Appellate Court Published Opinions

Date | Docket # | Title
--- | --- | ---
Aug. 8, 2013 | A-3582-10 | ELIZABETH GNALL VS. JAMES GNALL (FM-02-2021-08, BERGEN COUNTY AND STATEWIDE)
Aug. 7, 2013 | --- | No Appellate opinions approved for publication.
Aug. 6, 2013 | --- | No Appellate opinions approved for publication.
Aug. 5, 2013 | A-0643-10 | BERNARD AND JEANNE ADLER VS. SAVE, N/K/A SAVE, A FRIEND TO HOMELESS ANIMALS (L-2611-07, MERCER COUNTY AND STATEWIDE)
Aug. 2, 2013 | --- | No Appellate opinions approved for publication.
Aug. 1, 2013 | --- | No Appellate opinions approved for publication.
July 31, 2013 | --- | No Appellate opinions approved for publication.
July 30, 2013 | A-1377-12 | CUMBERLAND COUNTY BOARD OF CHOSEN FREEHOLDERS VS. VITETTA GROUP, P.C., ET AL. (L-962-07, CUMBERLAND COUNTY AND STATEWIDE)
July 30, 2013 | A-3642-12 | IN THE MATTER OF REGISTRANT T.H.: APPLICATION FOR JUDICIAL REVIEW OF NOTIFICATION AND TIER CLASSIFICATION (12010013, ATLANTIC COUNTY AND STATEWIDE) (RECORD IMPOUNDED)
July 29, 2013 | --- | No Appellate opinions approved for publication.
July 26, 2013 | --- | No Appellate opinions approved for publication.

Squibs: 2012-13 |2011-12 |2010-11 |2009-10 |2008-09 | 2007-08 | 2006-07
Privacy Policy | Contact Us | ©
New Jersey Judiciary